#!/bin/sh
# Franki/Earlgrey bootcfg.sh, last modified 01/03/2004 by WmT

do_grub()
{
	if [ -z "$1" ] ; then
		echo "$0: No KERNEL [or ROOTDEV]" 1>&2
		exit 1
	else
		KERNEL=`basename $1`
		shift
	fi

	if [ -z "$1" ] ; then
		echo "$0: No ROOTDEV" 1>&2
		exit 1
	else
		ROOTDEV=$1
		shift
	fi

	cat <<EOF
# GRUB 0.5.95 wills 12/9/2000
# Modified for willow, 01/02/2004

#'color' doesn't work as advertised!
#color BROWN/BLACK BLUE/YELLOW
color 2 14

#device (fd0) /floppy-image
#device (fd0) /dev/sd0

#
#       Linux from /dev/hda1
#
title Willow Linux
	root (hd0,0)
	kernel (hd0,0)/linux/boot/vm2040.lx root=/dev/hda1 rw
	boot

#
#       DOS from "C:"
#
title (Free)DOS/C:
	root (hd0,0)
	makeactive
	chainloader +1
	boot

##
##	tempOS (testing)
##
#title ...Testing
#	root (fd0)
#	kernel (fd0)/tempOS
#	boot

#
#	Misc useful
#
title Floppy
	root (fd0)
	chainloader +1
	boot
	reboot
title Reboot
	reboot
title Halt
	halt
EOF
}

do_loadlin_cfg()
{
	if [ -z "$1" ] ; then
		echo "$0: No KERNEL [or ROOTDEV]" 1>&2
		exit 1
	else
		KERNEL=`basename $1`
		shift
	fi

	if [ -z "$1" ] ; then
		echo "$0: No ROOTDEV" 1>&2
		exit 1
	else
		ROOTDEV=$1
		shift
	fi

	cat <<EOF
$KERNEL
root=/dev/${ROOTDEV} rw

ramdisk=0,no
#initrd=initrd.mnz ramdisk_size=1536

#--kernel parameters
debug
no387
#--graphics?
#	vga=ask,vga=extended
#	vga=normal
#--confused ide0 interface?
#	ide0=noprobe ide0=0x1f0,0x3f6,14
#--ZIP
#	aha152x=0x140,10,7,1
#	max_scsi_luns=1
#--OTHER
#ether=10,0x280,0xc8000,0xcbfff,eth0
#sound=0x0TTPPPID
EOF
}

do_loadlin_dev()
{
	if [ -z "$1" ] ; then
		echo "$0: No CFGFILE" 1>&2
		exit 1
	else
		CFGFILE=$1
		shift
	fi

	if [ -z "$1" ] ; then
		echo "$0: No ROOTDEV" 1>&2
		exit 1
	else
		ROOTDEV=$1
		shift
	fi

	cat <<EOF
loadlin.exe @${CFGFILE} boot=/dev/${ROOTDEV} root=/dev/${ROOTDEV}
EOF
}

do_loadlin_rd()
{
	if [ -z "$1" ] ; then
		echo "$0: No CFGFILE" 1>&2
		exit 1
	else
		CFGFILE=$1
		shift
	fi

	if [ -z "$1" ] ; then
		echo "$0: No RAMDISK" 1>&2
		exit 1
	else
		RAMDISK=$1
		shift
	fi

	cat <<EOF
loadlin.exe @${CFGFILE} initrd=`basename ${RAMDISK}` ramdisk_size=1536 root=/dev/ram
EOF
}

do_loadlin()
{
	if [ -z "$1" ] ; then
		echo "$0: No KERNEL [or ROOTDEV]" 1>&2
		exit 1
	else
		KERNEL=`basename $1`
		shift
	fi

	if [ -z "$1" ] ; then
		echo "$0: No ROOTDEV" 1>&2
		exit 1
	else
		ROOTDEV=$1
		shift
	fi

	if [ -z "$1" ] ; then
		echo "$0: No RAMDISK" 1>&2
		exit 1
	else
		RAMDISK=$1
		shift
	fi

	CFGFILE=`echo $KERNEL | sed 's/.lx$/.cfg/'`
	$0 loadlin-cfg $KERNEL $ROOTDEV > $CFGFILE

	KDIGS=`echo ${CFGFILE} | sed 's%[-/.a-z]%%g'`
	MDIGS=`basename ${RAMDISK} | sed 's%[-/.a-z]%%g' | sed 's/\.[a-z]*//'`
	$0 loadlin-dev ${CFGFILE} ${ROOTDEV} > ${KDIGS}${ROOTDEV}.bat
	$0 loadlin-rd ${CFGFILE} ${RAMDISK} > ${KDIGS}${MDIGS}.bat
}

ACTION=$1
[ "$1" ] && shift
case $ACTION in
grub)	## output menu.lst file for GNU GrUB bootloader
	do_grub $* || exit 1
	;;
loadlin-cfg)	## output config file for loadlin
	do_loadlin_cfg $* || exit 1
	;;
loadlin-dev)	## output batch file for loadlin/device
	do_loadlin_dev $* || exit 1
	;;
loadlin-rd)	## output batch file for loadlin/ramdisk
	do_loadlin_rd $* || exit 1
	;;
loadlin)	## output all loadlin files
	do_loadlin $* || exit 1
	;;
*)
	if [ -n "$COMMAND" -a "$COMMAND" != 'help' ] ; then
		echo "$0: Unrecognised command '$COMMAND'" 1>&2
	fi
	echo "$0: Usage:" 1>&2
	grep "^[0-9a-z-]*)" $0 | sed "s/^/	/" 1>&2
	exit 1
	;;
esac
